@@ -31,6 +31,8 @@
 #' \item{theta_sd}{Posterior samples of the standard deviation of theta.}
 #' \item{z}{Posterior samples of the z parameter, represented as a 3-dimensional matrix where the last axis denotes the dimension of the latent space.}
 #' \item{w}{Posterior samples of the w parameter, represented as a 3-dimensional matrix where the last axis denotes the dimension of the latent space.}
+#' \item{z_raw}{Posterior samples of the z parameter without procrustes matching.}
+#' \item{w_raw}{Posterior samples of the w parameter without procrustes matching.}
 #' \item{pi}{Posterior samples of phi which is indicator of spike and slab prior. If phi is 1, log gamma follows the slab prior, otherwise follows the spike prior. }
 #' \item{accept_beta}{Acceptance ratio for the beta parameter.}
 #' \item{accept_theta}{Acceptance ratio for the theta parameter.}
@@ -155,6 +157,8 @@ cat("\n")
                  gamma          = output$gamma,
                  z              = z.proc,
                  w              = w.proc,
+                 z_raw          = output$z,
+                 w_raw          = output$w,
                  pi             = output$pi,
                  accept_beta    = output$accept_beta,
                  accept_theta   = output$accept_theta,
