@@ -28,6 +28,8 @@
 #' \item{gamma}{Posterior samples of the gamma parameter.}
 #' \item{z}{Posterior samples of the z parameter, represented as a 3-dimensional matrix where the last axis denotes the dimension of the latent space.}
 #' \item{w}{Posterior samples of the w parameter, represented as a 3-dimensional matrix where the last axis denotes the dimension of the latent space.}
+#' \item{z_raw}{Posterior samples of the z parameter without procrustes matching.}
+#' \item{w_raw}{Posterior samples of the w parameter without procrustes matching.}
 #' \item{accept_beta}{Acceptance ratio for the beta parameter.}
 #' \item{accept_theta}{Acceptance ratio for the theta parameter.}
 #' \item{accept_z}{Acceptance ratio for the z parameter.}
@@ -148,6 +150,8 @@ cat("\n")
                  gamma          = output$gamma,
                  z              = z.proc,
                  w              = w.proc,
+                 z_raw          = output$z,
+                 w_raw          = output$w,
                  pi             = output$pi,
                  accept_beta    = output$accept_beta,
                  accept_theta   = output$accept_theta,
